@@ -19,7 +19,7 @@
 #ifndef HOSTS_GATHERER_H__
 #define HOSTS_GATHERER_H__
 
-#include <netinet/in.h> /* for in_addr */
+#include <netinet/in.h>         /* for in_addr */
 #include "arglists.h"
 
 #ifndef INADDR_NONE
@@ -32,20 +32,21 @@
 
 
 /* Flags for hg_hlobals */
-#define HG_NFS                1 
+#define HG_NFS                1
 #define HG_DNS_AXFR           2
 #define HG_SUBNET             4
 #define HG_PING       	      8
-#define HG_REVLOOKUP 	     16  /* Are we allowed to use the DNS ? */
-#define HG_REVLOOKUP_AS_PING 32 
+#define HG_REVLOOKUP 	     16 /* Are we allowed to use the DNS ? */
+#define HG_REVLOOKUP_AS_PING 32
 #define HG_DISTRIBUTE	     64
 
-struct hg_host {
-  char * hostname;	/**< Host name                    */
-  char * domain;		/**< Same pointer as hostname! Don't free it! */
-  struct in_addr addr;	/**< Host IP   	        	  */
-  struct in6_addr in6addr; /* Host IP */
-  int    cidr_netmask;	/**< CIDR-format netmask          */
+struct hg_host
+{
+  char *hostname;       /**< Host name                    */
+  char *domain;                 /**< Same pointer as hostname! Don't free it! */
+  struct in_addr addr;  /**< Host IP   	        	  */
+  struct in6_addr in6addr;      /* Host IP */
+  int cidr_netmask;     /**< CIDR-format netmask          */
   /* When given a /N notation, we 
      put this as the upper limit
      of the network */
@@ -53,26 +54,27 @@ struct hg_host {
   struct in_addr max;
   struct in6_addr min6;
   struct in6_addr max6;
-  int use_max:1;	/* use the field above ?	*/
-  unsigned int    tested:1;
-  unsigned int    alive:1;
-  struct hg_host * next;
+  int use_max:1;                /* use the field above ?        */
+  unsigned int tested:1;
+  unsigned int alive:1;
+  struct hg_host *next;
 };
 
-struct hg_globals {
-	struct hg_host * host_list;    /**< List of tested hosts.       */
-	struct hg_host * tested;       /**< Tested subnets and domains. */
-	int		  flags;       /**< Options.		        */
-	char 		* input;       /**< e.g. hostname               */
-	char 		* marker;
-	int	counter;
-	unsigned int	distribute;
-	};
+struct hg_globals
+{
+  struct hg_host *host_list;           /**< List of tested hosts.       */
+  struct hg_host *tested;              /**< Tested subnets and domains. */
+  int flags;                           /**< Options.		        */
+  char *input;                         /**< e.g. hostname               */
+  char *marker;
+  int counter;
+  unsigned int distribute;
+};
 
-struct hg_globals * hg_init (char *, int);
+struct hg_globals *hg_init (char *, int);
 int hg_next_host (struct hg_globals *, struct in6_addr *, char *, int);
 void hg_cleanup (struct hg_globals *);
 
-int hg_test_syntax(char * hostname, int flags);
+int hg_test_syntax (char *hostname, int flags);
 
 #endif
