@@ -38,11 +38,13 @@
  * The module reuses glib datatypes and api for memory management and logging.
  */
 
-#include <stdio.h> /* for fprintf */
-#include <string.h> /* for strlen */
-#include <stdlib.h> /* for atoi */
-#include <syslog.h> /* for syslog */
-#include <unistd.h> /* for getpid */
+#include <stdio.h>              /* for fprintf */
+#include <string.h>             /* for strlen */
+#include <stdlib.h>             /* for atoi */
+#define SYSLOG_NAMES
+#include <syslog.h>             /* for syslog */
+#undef SYSLOG_NAMES
+#include <unistd.h>             /* for getpid */
 #include <libgen.h>
 #include <errno.h>
 
@@ -56,12 +58,14 @@
  */
 typedef struct
 {
-  gchar *log_domain;          ///< Affected logdomain e.g libnasl.
-  gchar *prepend_string;      ///< Prepend this string before every message.
-  gchar *prepend_time_format; ///< If prependstring has %t, format for strftime.
-  gchar *log_file;            ///< Where to log to.
-  GLogLevelFlags *default_level; ///< What severity level to use as default.
-  GIOChannel *log_channel;    ///< Gio Channel - FD holder for logfile.
+  gchar *log_domain;            ///< Affected logdomain e.g libnasl.
+  gchar *prepend_string;        ///< Prepend this string before every message.
+  gchar *prepend_time_format;   ///< If prependstring has %t, format for strftime.
+  gchar *log_file;              ///< Where to log to.
+  GLogLevelFlags *default_level;        ///< What severity level to use as default.
+  GIOChannel *log_channel;      ///< Gio Channel - FD holder for logfile.
+  gchar *syslog_facility;       ///< Syslog facility to use for syslog logging.
+  gchar *syslog_ident;          ///< Syslog ident to use for syslog logging.
 } openvas_logging_t;
 
 
@@ -123,6 +127,29 @@ level_int_from_string (const gchar * level)
   return 0;
 }
 
+/**
+ * @brief Return the integer corresponding to a syslog facility string.
+ *
+ * @param facility Facility name.
+ *
+ * @return Facility integer if facility matches a facility name, else LOG_LOCAL0.
+ */
+static gint
+facility_int_from_string (const gchar * facility)
+{
+  if (facility && strlen (facility) > 0)
+    {
+      int i = 0;
+      while (facilitynames[i].c_name != NULL)
+        {
+          if (g_ascii_strcasecmp (facility, facilitynames[i].c_name) == 0)
+            return facilitynames[i].c_val;
+          i++;
+        }
+    }
+  return LOG_LOCAL0;
+}
+
 /**
  * @brief Loads parameters from a config file into a linked list.
  *
@@ -149,7 +176,7 @@ load_log_configuration (gchar * config_file)
   gchar **group;
 
   /* Structure to hold per group settings. */
-  openvas_logging_t * log_domain_entry;
+  openvas_logging_t *log_domain_entry;
   /* The link list for the structure above and it's tmp helper */
   GSList *log_domain_list = NULL;
 
@@ -181,6 +208,8 @@ load_log_configuration (gchar * config_file)
       log_domain_entry->log_file = NULL;
       log_domain_entry->default_level = NULL;
       log_domain_entry->log_channel = NULL;
+      log_domain_entry->syslog_facility = NULL;
+      log_domain_entry->syslog_ident = NULL;
 
 
       /* Look for the prepend string. */
@@ -217,6 +246,24 @@ load_log_configuration (gchar * config_file)
           g_free (level);
         }
 
+      /* Look for the syslog_facility string. */
+      if (g_key_file_has_key (key_file, *group, "syslog_facility", &error))
+        {
+          log_domain_entry->syslog_facility =
+            g_key_file_get_value (key_file, *group, "syslog_facility", &error);
+        }
+      else
+        log_domain_entry->syslog_facility = "local0";
+
+      /* Look for the syslog_ident string. */
+      if (g_key_file_has_key (key_file, *group, "syslog_ident", &error))
+        {
+          log_domain_entry->syslog_ident =
+            g_key_file_get_value (key_file, *group, "syslog_ident", &error);
+        }
+      else
+        log_domain_entry->syslog_ident =  g_strdup (*group);
+
       /* Attach the struct to the list. */
       log_domain_list = g_slist_prepend (log_domain_list, log_domain_entry);
       group++;
@@ -239,7 +286,7 @@ void
 free_log_configuration (GSList * log_domain_list)
 {
   GSList *log_domain_list_tmp;
-  openvas_logging_t * log_domain_entry;
+  openvas_logging_t *log_domain_entry;
 
   /* Free the struct fields then the struct and then go the next
    * item in the link list.
@@ -297,6 +344,9 @@ openvas_log_silent (const char *log_domain, GLogLevelFlags log_level,
  * @param message    A string containing the log message.
  * @param openvas_log_config_list (ignored) A pointer to the configuration
  *                                linked list.
+ *
+ * @TODO: syslog logging is now handled in openvas_log_func, do we need a
+ * separate handler for this?
  */
 static void
 openvas_syslog_func (const char *log_domain, GLogLevelFlags log_level,
@@ -304,30 +354,30 @@ openvas_syslog_func (const char *log_domain, GLogLevelFlags log_level,
 {
   switch (log_level)
     {
-      case G_LOG_FLAG_FATAL:
-        syslog (LOG_ALERT, "%s", message);
-        break;
-      case G_LOG_LEVEL_ERROR:
-        syslog (LOG_ERR, "%s", message);
-        break;
-      case G_LOG_LEVEL_CRITICAL:
-        syslog (LOG_CRIT, "%s", message);
-        break;
-      case G_LOG_LEVEL_WARNING:
-        syslog (LOG_WARNING, "%s", message);
-        break;
-      case G_LOG_LEVEL_MESSAGE:
-        syslog (LOG_NOTICE, "%s", message);
-        break;
-      case G_LOG_LEVEL_INFO:
-        syslog (LOG_INFO, "%s", message);
-        break;
-      case G_LOG_LEVEL_DEBUG:
-        syslog (LOG_DEBUG, "%s", message);
-        break;
-      default:
-        syslog (LOG_INFO, "%s", message);
-        break;
+    case G_LOG_FLAG_FATAL:
+      syslog (LOG_ALERT, "%s", message);
+      break;
+    case G_LOG_LEVEL_ERROR:
+      syslog (LOG_ERR, "%s", message);
+      break;
+    case G_LOG_LEVEL_CRITICAL:
+      syslog (LOG_CRIT, "%s", message);
+      break;
+    case G_LOG_LEVEL_WARNING:
+      syslog (LOG_WARNING, "%s", message);
+      break;
+    case G_LOG_LEVEL_MESSAGE:
+      syslog (LOG_NOTICE, "%s", message);
+      break;
+    case G_LOG_LEVEL_INFO:
+      syslog (LOG_INFO, "%s", message);
+      break;
+    case G_LOG_LEVEL_DEBUG:
+      syslog (LOG_DEBUG, "%s", message);
+      break;
+    default:
+      syslog (LOG_INFO, "%s", message);
+      break;
     }
 }
 
@@ -368,6 +418,8 @@ openvas_log_func (const char *log_domain, GLogLevelFlags log_level,
   gchar *log_file = "-";
   GLogLevelFlags default_level = G_LOG_LEVEL_DEBUG;
   channel = NULL;
+  gchar *syslog_facility = "local0";
+  gchar *syslog_ident = NULL;
 
   /* Let's load the default configuration file directives from the
    * linked list. Scanning the link list twice is inefficient but
@@ -402,6 +454,8 @@ openvas_log_func (const char *log_domain, GLogLevelFlags log_level,
                 default_level = *log_domain_entry->default_level;
               if (log_domain_entry->log_channel)
                 channel = log_domain_entry->log_channel;
+              if (log_domain_entry->syslog_facility)
+                syslog_facility = log_domain_entry->syslog_facility;
               break;
             }
 
@@ -438,6 +492,8 @@ openvas_log_func (const char *log_domain, GLogLevelFlags log_level,
               if (log_domain_entry->default_level)
                 default_level = *log_domain_entry->default_level;
               channel = log_domain_entry->log_channel;
+              syslog_facility = log_domain_entry->syslog_facility;
+              syslog_ident = log_domain_entry->syslog_ident;
               break;
             }
 
@@ -550,10 +606,9 @@ openvas_log_func (const char *log_domain, GLogLevelFlags log_level,
    * print out the message.
    */
   GString *log_str = g_string_new ("");
-  g_string_append_printf (log_str,
-                          "%s%s%s%s %s\n",
-                          log_domain ? log_domain : "", log_separator,
-                          prepend, log_separator, message);
+  g_string_append_printf (log_str, "%s%s%s%s %s\n",
+                          log_domain ? log_domain : "", log_separator, prepend,
+                          log_separator, message);
 
   gchar *tmpstr = g_string_free (log_str, FALSE);
   /* Output everything to stderr if logfile is "-". */
@@ -562,6 +617,46 @@ openvas_log_func (const char *log_domain, GLogLevelFlags log_level,
       fprintf (stderr, "%s", tmpstr);
       fflush (stderr);
     }
+  /* Output everything to syslog if logfile is "syslog" */
+  else if (g_ascii_strcasecmp (log_file, "syslog") == 0)
+    {
+      int facility = facility_int_from_string (syslog_facility);
+      int syslog_level = LOG_INFO;
+
+      openlog (syslog_ident, LOG_CONS | LOG_PID | LOG_NDELAY, facility);
+
+      switch (log_level)
+        {
+        case G_LOG_FLAG_FATAL:
+          syslog_level = LOG_ALERT;
+          break;
+        case G_LOG_LEVEL_ERROR:
+          syslog_level = LOG_ERR;
+          break;
+        case G_LOG_LEVEL_CRITICAL:
+          syslog_level = LOG_CRIT;
+          break;
+        case G_LOG_LEVEL_WARNING:
+          syslog_level = LOG_WARNING;
+          break;
+        case G_LOG_LEVEL_MESSAGE:
+          syslog_level = LOG_NOTICE;
+          break;
+        case G_LOG_LEVEL_INFO:
+          syslog_level = LOG_INFO;
+          break;
+        case G_LOG_LEVEL_DEBUG:
+          syslog_level = LOG_DEBUG;
+          break;
+        default:
+          syslog_level = LOG_INFO;
+          break;
+        }
+
+      syslog (syslog_level, "%s", message);
+
+      closelog ();
+    }
   else
     {
       /* Open a channel and store it in the struct or
@@ -579,10 +674,9 @@ openvas_log_func (const char *log_domain, GLogLevelFlags log_level,
               g_error_free (error);
 
               /* Ensure directory exists. */
-              if (g_mkdir_with_parents (dir, 0755)) /* "rwxr-xr-x" */
+              if (g_mkdir_with_parents (dir, 0755))     /* "rwxr-xr-x" */
                 {
-                  g_warning ("Failed to create log file directory %s: %s",
-                             dir,
+                  g_warning ("Failed to create log file directory %s: %s", dir,
                              strerror (errno));
                   g_free (log);
                   g_free (tmpstr);
@@ -596,8 +690,7 @@ openvas_log_func (const char *log_domain, GLogLevelFlags log_level,
               channel = g_io_channel_new_file (log_file, "a", &error);
               if (!channel)
                 {
-                  g_error ("Can not open '%s' logfile: %s",
-                           log_file,
+                  g_error ("Can not open '%s' logfile: %s", log_file,
                            error->message);
                 }
             }
@@ -639,11 +732,9 @@ setup_log_handlers (GSList * openvas_log_config_list)
 
           GLogFunc logfunc =
 #if 0
-                            (!strcmp (log_domain_entry, "syslog"))
-                             ? openvas_syslog_func
-                             :
+            (!strcmp (log_domain_entry, "syslog")) ? openvas_syslog_func :
 #endif
-              openvas_log_func;
+            openvas_log_func;
 
           if (g_ascii_strcasecmp (log_domain_entry->log_domain, "*"))
             {
@@ -656,8 +747,7 @@ setup_log_handlers (GSList * openvas_log_config_list)
                                                    G_LOG_LEVEL_ERROR |
                                                    G_LOG_FLAG_FATAL |
                                                    G_LOG_FLAG_RECURSION),
-                                 (GLogFunc) logfunc,
-                                 openvas_log_config_list);
+                                 (GLogFunc) logfunc, openvas_log_config_list);
             }
           else
             {
@@ -675,6 +765,5 @@ setup_log_handlers (GSList * openvas_log_config_list)
                                        | G_LOG_LEVEL_CRITICAL |
                                        G_LOG_LEVEL_ERROR | G_LOG_FLAG_FATAL |
                                        G_LOG_FLAG_RECURSION),
-                     (GLogFunc) openvas_log_func,
-                     openvas_log_config_list);
+                     (GLogFunc) openvas_log_func, openvas_log_config_list);
 }
