@@ -33,17 +33,29 @@
 
 /** @todo Ensure that every global init gets a free. */
 
+#ifdef _WIN32
+
+#define WINVER 0x0501
+#define SHUT_RDWR 2
+#include <winsock2.h>
+#include <winsock.h>
+
+#else
+
 #include <arpa/inet.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <gcrypt.h>
-#include <glib.h>
 #include <netdb.h>
 #include <signal.h>
-#include <string.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+
+#endif
+
 #include <unistd.h>
+#include <gcrypt.h>
+#include <glib.h>
+#include <string.h>
 
 #include "openvas_server.h"
 
@@ -73,14 +85,19 @@ struct sockaddr_in address;
  * @return 0 on success, -1 on error.
  */
 int
-openvas_server_open (gnutls_session_t * session,
-                     const char *host, int port)
+openvas_server_open (gnutls_session_t * session, const char *host, int port)
 {
   int server_socket;
   struct addrinfo address_hints;
   struct addrinfo *addresses, *address;
   gchar *port_string;
+#ifdef _WIN32
+  WSADATA wsaData;
+#endif
+
+#ifndef _WIN32
   struct sigaction new_action, original_action;
+#endif
 
   /** @todo Ensure that host and port have sane values. */
   /** @todo Improve logging. */
@@ -91,7 +108,7 @@ openvas_server_open (gnutls_session_t * session,
 
   /* Initialize security library. */
 
-  int ret = gnutls_global_init();
+  int ret = gnutls_global_init ();
   if (ret < 0)
     {
       g_message ("Failed to initialize GNUTLS.");
@@ -126,9 +143,10 @@ openvas_server_open (gnutls_session_t * session,
     }
 
   const int kx_priority[] = { GNUTLS_KX_DHE_RSA,
-                              GNUTLS_KX_RSA,
-                              GNUTLS_KX_DHE_DSS,
-                              0 };
+    GNUTLS_KX_RSA,
+    GNUTLS_KX_DHE_DSS,
+    0
+  };
   if (gnutls_kx_set_priority (*session, kx_priority))
     {
       g_message ("Failed to set server key exchange priority.");
@@ -137,9 +155,7 @@ openvas_server_open (gnutls_session_t * session,
       return -1;
     }
 
-  if (gnutls_credentials_set (*session,
-                              GNUTLS_CRD_CERTIFICATE,
-                              credentials))
+  if (gnutls_credentials_set (*session, GNUTLS_CRD_CERTIFICATE, credentials))
     {
       g_message ("Failed to set server credentials.");
       gnutls_deinit (*session);
@@ -151,19 +167,31 @@ openvas_server_open (gnutls_session_t * session,
 
   port_string = g_strdup_printf ("%i", port);
 
+  /* WSA Start for win32 */
+#ifdef _WIN32
+  if (WSAStartup (MAKEWORD (2, 2), &wsaData))
+    {
+      g_message ("WSAStartup failed");
+      gnutls_deinit (*session);
+      gnutls_certificate_free_credentials (credentials);
+      return -1;
+    }
+#endif
+
   /* Get all possible addresses. */
 
   memset (&address_hints, 0, sizeof (address_hints));
-  address_hints.ai_family = AF_UNSPEC;     /* IPv4 or IPv6. */
+  address_hints.ai_family = AF_UNSPEC;  /* IPv4 or IPv6. */
   address_hints.ai_socktype = SOCK_STREAM;
+#ifndef _WIN32
   address_hints.ai_flags = AI_NUMERICSERV;
+#endif
   address_hints.ai_protocol = 0;
 
   if (getaddrinfo (host, port_string, &address_hints, &addresses))
     {
       g_free (port_string);
-      g_message ("Failed to get server addresses for %s: %s",
-                 host,
+      g_message ("Failed to get server addresses for %s: %s", host,
                  gai_strerror (errno));
       gnutls_deinit (*session);
       gnutls_certificate_free_credentials (credentials);
@@ -191,8 +219,7 @@ openvas_server_open (gnutls_session_t * session,
 
       /* Connect to server. */
 
-      if (connect (server_socket, address->ai_addr, address->ai_addrlen)
-          == -1)
+      if (connect (server_socket, address->ai_addr, address->ai_addrlen) == -1)
         {
           close (server_socket);
           continue;
@@ -215,14 +242,17 @@ openvas_server_open (gnutls_session_t * session,
   /* Complete setup of server session. */
 
   gnutls_transport_set_ptr (*session,
-                            (gnutls_transport_ptr_t) GSIZE_TO_POINTER(server_socket));
+                            (gnutls_transport_ptr_t)
+                            GSIZE_TO_POINTER (server_socket));
 
+#ifndef _WIN32
   new_action.sa_flags = 0;
   if (sigemptyset (&new_action.sa_mask))
     return -1;
   new_action.sa_handler = SIG_IGN;
   if (sigaction (SIGPIPE, &new_action, &original_action))
     return -1;
+#endif
 
   while (1)
     {
@@ -231,18 +261,26 @@ openvas_server_open (gnutls_session_t * session,
         break;
       if (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED)
         continue;
-      g_message ("Failed to shake hands with server: %s", gnutls_strerror (ret));
+      g_message ("Failed to shake hands with server: %s",
+                 gnutls_strerror (ret));
       if (shutdown (server_socket, SHUT_RDWR) == -1)
         g_message ("Failed to shutdown server socket");
       close (server_socket);
       gnutls_deinit (*session);
       gnutls_certificate_free_credentials (credentials);
+
+#ifndef _WIN32
       sigaction (SIGPIPE, &original_action, NULL);
+#endif
+
       return -1;
     }
   g_message ("   Shook hands with server.");
 
-  if (sigaction (SIGPIPE, &original_action, NULL)) return -1;
+#ifndef _WIN32
+  if (sigaction (SIGPIPE, &original_action, NULL))
+    return -1;
+#endif
 
   return server_socket;
 }
@@ -258,10 +296,12 @@ openvas_server_open (gnutls_session_t * session,
 int
 openvas_server_close (int socket, gnutls_session_t session)
 {
+#ifndef _WIN32
   struct sigaction new_action, original_action;
 
   /* Turn off blocking. */
-  if (fcntl (socket, F_SETFL, O_NONBLOCK) == -1) return -1;
+  if (fcntl (socket, F_SETFL, O_NONBLOCK) == -1)
+    return -1;
 
   new_action.sa_flags = 0;
   if (sigemptyset (&new_action.sa_mask))
@@ -269,10 +309,14 @@ openvas_server_close (int socket, gnutls_session_t session)
   new_action.sa_handler = SIG_IGN;
   if (sigaction (SIGPIPE, &new_action, &original_action))
     return -1;
+#endif
 
   gnutls_bye (session, GNUTLS_SHUT_RDWR);
 
-  if (sigaction (SIGPIPE, &original_action, NULL)) return -1;
+#ifndef _WIN32
+  if (sigaction (SIGPIPE, &original_action, NULL))
+    return -1;
+#endif
 
   close (socket);
   gnutls_global_deinit ();
@@ -291,22 +335,22 @@ openvas_server_close (int socket, gnutls_session_t session)
  * @return 0 on success, -1 on error, -2 on connect interrupt.
  */
 int
-openvas_server_connect (int server_socket,
-                        struct sockaddr_in* server_address,
-                        gnutls_session_t* server_session,
-                        gboolean interrupted)
+openvas_server_connect (int server_socket, struct sockaddr_in *server_address,
+                        gnutls_session_t * server_session, gboolean interrupted)
 {
   int ret;
   socklen_t ret_len = sizeof (ret);
+
+#ifndef _WIN32
   struct sigaction new_action, original_action;
+#endif
 
   if (interrupted)
     {
-      if (getsockopt (server_socket, SOL_SOCKET, SO_ERROR, &ret, &ret_len)
-          == -1)
+      if (getsockopt (server_socket, SOL_SOCKET, SO_ERROR, &ret, &ret_len) ==
+          -1)
         {
-          g_warning ("%s: failed to get socket option: %s\n",
-                     __FUNCTION__,
+          g_warning ("%s: failed to get socket option: %s\n", __FUNCTION__,
                      strerror (errno));
           return -1;
         }
@@ -320,21 +364,29 @@ openvas_server_connect (int server_socket,
         }
       if (ret)
         {
-          if (ret == EINPROGRESS) return -2;
+
+#ifndef _WIN32
+          if (ret == EINPROGRESS)
+            return -2;
+#endif
+
           g_warning ("%s: failed to connect to server (interrupted): %s\n",
-                     __FUNCTION__,
-                     strerror (ret));
+                     __FUNCTION__, strerror (ret));
           return -1;
         }
     }
-  else if (connect (server_socket,
-                    (struct sockaddr *) server_address,
-                    sizeof (struct sockaddr_in))
-           == -1)
+  else
+    if (connect
+        (server_socket, (struct sockaddr *) server_address,
+         sizeof (struct sockaddr_in)) == -1)
     {
-      if (errno == EINPROGRESS) return -2;
-      g_warning ("%s: failed to connect to server: %s\n",
-                 __FUNCTION__,
+
+#ifndef _WIN32
+      if (errno == EINPROGRESS)
+        return -2;
+#endif
+
+      g_warning ("%s: failed to connect to server: %s\n", __FUNCTION__,
                  strerror (errno));
       return -1;
     }
@@ -343,14 +395,17 @@ openvas_server_connect (int server_socket,
   /* Complete setup of server session. */
 
   gnutls_transport_set_ptr (*server_session,
-                            (gnutls_transport_ptr_t) GSIZE_TO_POINTER(server_socket));
+                            (gnutls_transport_ptr_t)
+                            GSIZE_TO_POINTER (server_socket));
 
+#ifndef _WIN32
   new_action.sa_flags = 0;
   if (sigemptyset (&new_action.sa_mask))
     return -1;
   new_action.sa_handler = SIG_IGN;
   if (sigaction (SIGPIPE, &new_action, &original_action))
     return -1;
+#endif
 
   while (1)
     {
@@ -359,17 +414,21 @@ openvas_server_connect (int server_socket,
         break;
       if (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED)
         continue;
-      g_warning ("%s: failed to shake hands with server: %s\n",
-                 __FUNCTION__,
+      g_warning ("%s: failed to shake hands with server: %s\n", __FUNCTION__,
                  gnutls_strerror (ret));
       if (shutdown (server_socket, SHUT_RDWR) == -1)
         g_message ("   Failed to shutdown server socket: %s\n",
                    strerror (errno));
+#ifndef _WIN32
       sigaction (SIGPIPE, &original_action, NULL);
+#endif
       return -1;
     }
 
-  if (sigaction (SIGPIPE, &original_action, NULL)) return -1;
+#ifndef _WIN32
+  if (sigaction (SIGPIPE, &original_action, NULL))
+    return -1;
+#endif
 
   return 0;
 }
@@ -382,13 +441,14 @@ openvas_server_connect (int server_socket,
  *
  * @return 0 on success, -1 on error.
  */
+#ifndef _WIN32
 int
-openvas_server_attach (int socket, gnutls_session_t* session)
+openvas_server_attach (int socket, gnutls_session_t * session)
 {
   struct sigaction new_action, original_action;
 
   gnutls_transport_set_ptr (*session,
-                            (gnutls_transport_ptr_t) GSIZE_TO_POINTER(socket));
+                            (gnutls_transport_ptr_t) GSIZE_TO_POINTER (socket));
 
   new_action.sa_flags = 0;
   if (sigemptyset (&new_action.sa_mask))
@@ -412,10 +472,12 @@ openvas_server_attach (int socket, gnutls_session_t* session)
     }
   g_message ("   Shook hands with peer.");
 
-  if (sigaction (SIGPIPE, &original_action, NULL)) return -1;
+  if (sigaction (SIGPIPE, &original_action, NULL))
+    return -1;
 
   return 0;
 }
+#endif
 
 /**
  * @brief Send a string to the server.
@@ -426,22 +488,28 @@ openvas_server_attach (int socket, gnutls_session_t* session)
  * @return 0 on success, 1 if server closed connection, -1 on error.
  */
 int
-openvas_server_send (gnutls_session_t* session, const char* string)
+openvas_server_send (gnutls_session_t * session, const char *string)
 {
+#ifndef _WIN32
   struct sigaction new_action, original_action;
+#endif
+
   size_t left = strlen (string);
 
+#ifndef _WIN32
   new_action.sa_flags = 0;
   if (sigemptyset (&new_action.sa_mask))
     return -1;
   new_action.sa_handler = SIG_IGN;
   if (sigaction (SIGPIPE, &new_action, &original_action))
     return -1;
+#endif
 
   while (left)
     {
       ssize_t count;
-      g_message ("   send %i from %.*s[...]", left, left < 30 ? left : 30, string);
+      g_message ("   send %i from %.*s[...]", left, left < 30 ? left : 30,
+                 string);
       count = gnutls_record_send (*session, string, left);
       if (count < 0)
         {
@@ -455,14 +523,22 @@ openvas_server_send (gnutls_session_t* session, const char* string)
               continue;
             }
           g_message ("Failed to write to server: %s", gnutls_strerror (count));
+
+#ifndef _WIN32
           sigaction (SIGPIPE, &original_action, NULL);
+#endif
+
           return -1;
         }
       if (count == 0)
         {
           /* Server closed connection. */
           g_message ("=  server closed\n");
+
+#ifndef _WIN32
           sigaction (SIGPIPE, &original_action, NULL);
+#endif
+
           return 1;
         }
       g_message ("=> %.*s", count, string);
@@ -471,7 +547,10 @@ openvas_server_send (gnutls_session_t* session, const char* string)
     }
   g_message ("=> done");
 
+#ifndef _WIN32
   sigaction (SIGPIPE, &original_action, NULL);
+#endif
+
   return 0;
 }
 
@@ -484,11 +563,11 @@ openvas_server_send (gnutls_session_t* session, const char* string)
  * @return 0 on success, -1 on error.
  */
 int
-openvas_server_sendf (gnutls_session_t* session, const char* format, ...)
+openvas_server_sendf (gnutls_session_t * session, const char *format, ...)
 {
   va_list args;
   va_start (args, format);
-  gchar* msg = g_strdup_vprintf (format, args);
+  gchar *msg = g_strdup_vprintf (format, args);
   int ret = openvas_server_send (session, msg);
   g_free (msg);
   va_end (args);
@@ -509,31 +588,34 @@ openvas_server_sendf (gnutls_session_t* session, const char* format, ...)
  * @return 0 on success, -1 on error.
  */
 int
-openvas_server_new (gnutls_connection_end_t end_type,
-                    gchar* ca_cert_file,
-                    gchar* cert_file,
-                    gchar* key_file,
-                    gnutls_session_t* server_session,
-                    gnutls_certificate_credentials_t* server_credentials)
+openvas_server_new (gnutls_connection_end_t end_type, gchar * ca_cert_file,
+                    gchar * cert_file, gchar * key_file,
+                    gnutls_session_t * server_session,
+                    gnutls_certificate_credentials_t * server_credentials)
 {
   // FIX static vars?
   const int protocol_priority[] = { GNUTLS_TLS1,
-                                    0 };
+    0
+  };
   const int cipher_priority[] = { GNUTLS_CIPHER_AES_128_CBC,
-                                  GNUTLS_CIPHER_3DES_CBC,
-                                  GNUTLS_CIPHER_AES_256_CBC,
-                                  GNUTLS_CIPHER_ARCFOUR_128,
-                                  0 };
+    GNUTLS_CIPHER_3DES_CBC,
+    GNUTLS_CIPHER_AES_256_CBC,
+    GNUTLS_CIPHER_ARCFOUR_128,
+    0
+  };
   const int comp_priority[] = { GNUTLS_COMP_ZLIB,
-                                GNUTLS_COMP_NULL,
-                                0 };
+    GNUTLS_COMP_NULL,
+    0
+  };
   const int kx_priority[] = { GNUTLS_KX_DHE_RSA,
-                              GNUTLS_KX_RSA,
-                              GNUTLS_KX_DHE_DSS,
-                              0 };
+    GNUTLS_KX_RSA,
+    GNUTLS_KX_DHE_DSS,
+    0
+  };
   const int mac_priority[] = { GNUTLS_MAC_SHA1,
-                               GNUTLS_MAC_MD5,
-                               0 };
+    GNUTLS_MAC_MD5,
+    0
+  };
 
   /* Turn off use of /dev/random, as this can block. */
 
@@ -555,13 +637,10 @@ openvas_server_new (gnutls_connection_end_t end_type,
       return -1;
     }
 
-  if (cert_file
-      && key_file
-      && (gnutls_certificate_set_x509_key_file (*server_credentials,
-                                                cert_file,
-                                                key_file,
-                                                GNUTLS_X509_FMT_PEM)
-          < 0))
+  if (cert_file && key_file
+      &&
+      (gnutls_certificate_set_x509_key_file
+       (*server_credentials, cert_file, key_file, GNUTLS_X509_FMT_PEM) < 0))
     {
       g_warning ("%s: failed to set credentials key file\n", __FUNCTION__);
       g_warning ("%s:   cert file: %s\n", __FUNCTION__, cert_file);
@@ -570,13 +649,11 @@ openvas_server_new (gnutls_connection_end_t end_type,
     }
 
   if (ca_cert_file
-      && (gnutls_certificate_set_x509_trust_file (*server_credentials,
-                                                  ca_cert_file,
-                                                  GNUTLS_X509_FMT_PEM)
-          < 0))
+      &&
+      (gnutls_certificate_set_x509_trust_file
+       (*server_credentials, ca_cert_file, GNUTLS_X509_FMT_PEM) < 0))
     {
-      g_warning ("%s: failed to set credentials trust file: %s\n",
-                 __FUNCTION__,
+      g_warning ("%s: failed to set credentials trust file: %s\n", __FUNCTION__,
                  ca_cert_file);
       goto server_free_fail;
     }
@@ -618,16 +695,14 @@ openvas_server_new (gnutls_connection_end_t end_type,
       goto server_fail;
     }
 
-  if (gnutls_credentials_set (*server_session,
-                              GNUTLS_CRD_CERTIFICATE,
-                              *server_credentials))
+  if (gnutls_credentials_set
+      (*server_session, GNUTLS_CRD_CERTIFICATE, *server_credentials))
     {
       g_warning ("%s: failed to set server credentials\n", __FUNCTION__);
       goto server_fail;
     }
 
-  gnutls_certificate_server_set_request (*server_session,
-                                         GNUTLS_CERT_REQUEST);
+  gnutls_certificate_server_set_request (*server_session, GNUTLS_CERT_REQUEST);
 
 #if 0
   // FIX admin also had this
@@ -637,10 +712,10 @@ openvas_server_new (gnutls_connection_end_t end_type,
 
   return 0;
 
- server_fail:
+server_fail:
   (void) gnutls_deinit (*server_session);
 
- server_free_fail:
+server_free_fail:
   gnutls_certificate_free_credentials (*server_credentials);
 
   return -1;
@@ -657,12 +732,12 @@ openvas_server_new (gnutls_connection_end_t end_type,
  * @return 0 success, -1 error.
  */
 int
-openvas_server_free (int server_socket,
-                     gnutls_session_t server_session,
-                     gnutls_certificate_credentials_t
-                     server_credentials)
+openvas_server_free (int server_socket, gnutls_session_t server_session,
+                     gnutls_certificate_credentials_t server_credentials)
 {
+#ifndef _WIN32
   struct sigaction new_action, original_action;
+#endif
 
   int count;
 
@@ -671,8 +746,7 @@ openvas_server_free (int server_socket,
   // FIX get flags first
   if (fcntl (server_socket, F_SETFL, 0L) == -1)
     {
-      g_warning ("%s: failed to set server socket flag: %s\n",
-                 __FUNCTION__,
+      g_warning ("%s: failed to set server socket flag: %s\n", __FUNCTION__,
                  strerror (errno));
       return -1;
     }
@@ -680,21 +754,24 @@ openvas_server_free (int server_socket,
 #if 1
   /* Turn off blocking. */
   // FIX get flags first
+#ifndef _WIN32
   if (fcntl (server_socket, F_SETFL, O_NONBLOCK) == -1)
     {
-      g_warning ("%s: failed to set server socket flag: %s\n",
-                 __FUNCTION__,
+      g_warning ("%s: failed to set server socket flag: %s\n", __FUNCTION__,
                  strerror (errno));
       return -1;
     }
 #endif
+#endif
 
+#ifndef _WIN32
   new_action.sa_flags = 0;
   if (sigemptyset (&new_action.sa_mask))
     return -1;
   new_action.sa_handler = SIG_IGN;
   if (sigaction (SIGPIPE, &new_action, &original_action))
     return -1;
+#endif
 
   count = 100;
   while (count)
@@ -715,23 +792,26 @@ openvas_server_free (int server_socket,
         }
       break;
     }
-  if (count == 0) g_message ("   Gave up trying to gnutls_bye\n");
+  if (count == 0)
+    g_message ("   Gave up trying to gnutls_bye\n");
 
-  if (sigaction (SIGPIPE, &original_action, NULL)) return -1;
+#ifndef _WIN32
+  if (sigaction (SIGPIPE, &original_action, NULL))
+    return -1;
 
   if (shutdown (server_socket, SHUT_RDWR) == -1)
     {
-      if (errno == ENOTCONN) return 0;
-      g_warning ("%s: failed to shutdown server socket: %s\n",
-                 __FUNCTION__,
+      if (errno == ENOTCONN)
+        return 0;
+      g_warning ("%s: failed to shutdown server socket: %s\n", __FUNCTION__,
                  strerror (errno));
       return -1;
     }
+#endif
 
   if (close (server_socket) == -1)
     {
-      g_warning ("%s: failed to close server socket: %s\n",
-                 __FUNCTION__,
+      g_warning ("%s: failed to close server socket: %s\n", __FUNCTION__,
                  strerror (errno));
       return -1;
     }
