@@ -43,38 +43,33 @@ extern "C"
 #endif
 
 #include <gnutls/gnutls.h>
+#ifdef _WIN32
+#include <winsock2.h>
+#else
 #include <netinet/ip.h>
+#endif
 
-int
-openvas_server_open (gnutls_session_t*, const char*, int);
+int openvas_server_open (gnutls_session_t *, const char *, int);
 
-int
-openvas_server_close (int, gnutls_session_t);
+int openvas_server_close (int, gnutls_session_t);
 
-int
-openvas_server_connect (int, struct sockaddr_in*, gnutls_session_t*, gboolean);
+int openvas_server_connect (int, struct sockaddr_in *, gnutls_session_t *,
+                            gboolean);
 
-int
-openvas_server_attach (int, gnutls_session_t*);
+int openvas_server_attach (int, gnutls_session_t *);
 
-int
-openvas_server_send (gnutls_session_t*, const char*);
+int openvas_server_send (gnutls_session_t *, const char *);
 
-int
-openvas_server_sendf (gnutls_session_t*, const char*, ...);
+int openvas_server_sendf (gnutls_session_t *, const char *, ...);
 
-int
-openvas_server_new (gnutls_connection_end_t, gchar*, gchar*, gchar*,
-                    gnutls_session_t*, gnutls_certificate_credentials_t*);
+int openvas_server_new (gnutls_connection_end_t, gchar *, gchar *, gchar *,
+                        gnutls_session_t *, gnutls_certificate_credentials_t *);
 
-int
-openvas_server_free (int,
-                     gnutls_session_t,
-                     gnutls_certificate_credentials_t);
+int openvas_server_free (int, gnutls_session_t,
+                         gnutls_certificate_credentials_t);
 
-int
-openvas_server_session_free (gnutls_session_t,
-                             gnutls_certificate_credentials_t);
+int openvas_server_session_free (gnutls_session_t,
+                                 gnutls_certificate_credentials_t);
 
 #if 0
 {
