@@ -43,12 +43,16 @@
  *       has to evaluated if that is okay or leads to memory leaks.
  */
 
-#include <stdio.h>
 #include <string.h>
+#include <stdio.h>
+#include "system.h"
 
 #include "nasl_wmi.h"
 #include "openvas_wmi_interface.h"
 
+#define IMPORT(var) char *var = get_str_local_var_by_name(lexic, #var)
+#define max 5
+
 /**
  * @brief Get a version string of the WMI implementation.
  *
@@ -60,8 +64,8 @@
 tree_cell *
 nasl_wmi_versioninfo (lex_ctxt * lexic)
 {
-  char * version = wmi_versioninfo ();
-  tree_cell * retc = alloc_tree_cell (0, NULL);
+  char *version = wmi_versioninfo ();
+  tree_cell *retc = alloc_tree_cell (0, NULL);
 
   if (!retc)
     return NULL;
@@ -99,15 +103,20 @@ nasl_wmi_versioninfo (lex_ctxt * lexic)
 tree_cell *
 nasl_wmi_connect (lex_ctxt * lexic)
 {
-  char *host = get_str_local_var_by_name (lexic, "host");
-  char *username = get_str_local_var_by_name (lexic, "username");
-  char *password = get_str_local_var_by_name (lexic, "password");
-  char *namespace = get_str_local_var_by_name (lexic, "ns");
-  WMI_HANDLE handle;
-  int value;
+  IMPORT (host);
+  IMPORT (username);
+  IMPORT (password);
+  IMPORT(ns);
 
-  if (namespace == NULL)
-    namespace = "root\\cimv2";
+  if (ns == NULL)
+    ns = "root\\cimv2";
+
+  char *argv[max];
+
+  WMI_HANDLE handle;
+  int argc = 5, value;
+  char *argv1 = "wmic";
+  char *argv2 = "-U";
 
   if ((host == NULL) || (username == NULL) || (password == NULL))
     {
@@ -122,12 +131,28 @@ nasl_wmi_connect (lex_ctxt * lexic)
       return NULL;
     }
 
+  argv[0] = (char *) emalloc (strlen (argv1));
+  argv[1] = (char *) emalloc (strlen (argv2));
+  argv[2] = (char *) emalloc (strlen (username) + strlen (password) + 1);
+  argv[3] = (char *) emalloc (strlen (host) + 2);
+  argv[4] = (char *) emalloc (strlen (ns));
+
+  // Construct the WMI query
+  strcpy (argv[0], argv1);
+  strcpy (argv[1], "-U");
+  strcpy (argv[2], username);
+  strcat (argv[2], "%");
+  strcat (argv[2], password);
+  strcpy (argv[3], "//");
+  strcat (argv[3], host);
+  strcpy (argv[4], ns);
+
   tree_cell *retc = alloc_tree_cell (0, NULL);
   if (!retc)
     return NULL;
 
   retc->type = CONST_INT;
-  value = wmi_connect (username, password, host, namespace, &handle);
+  value = wmi_connect (argc, argv, &handle);
   if (value == -1)
     {
       fprintf (stderr, "nasl_wmi_connect: WMI Connect failed\n");
@@ -238,11 +263,15 @@ nasl_wmi_query (lex_ctxt * lexic)
 tree_cell *
 nasl_wmi_connect_rsop (lex_ctxt * lexic)
 {
-  char *host = get_str_local_var_by_name (lexic, "host");
-  char *username = get_str_local_var_by_name (lexic, "username");
-  char *password = get_str_local_var_by_name (lexic, "password");
+  IMPORT (host);
+  IMPORT (username);
+  IMPORT (password);
+  char *argv[4];
+
   WMI_HANDLE handle;
-  int value;
+  int argc = 4, value;
+  char *argv1 = "wmic";
+  char *argv2 = "-U";
 
   if ((host == NULL) || (username == NULL) || (password == NULL))
     {
@@ -257,15 +286,29 @@ nasl_wmi_connect_rsop (lex_ctxt * lexic)
       return NULL;
     }
 
+  argv[0] = (char *) emalloc (strlen (argv1));
+  argv[1] = (char *) emalloc (strlen (argv2));
+  argv[2] = (char *) emalloc (strlen (username) + strlen (password) + 1);
+  argv[3] = (char *) emalloc (strlen (host) + 2);
+
+  // Construct the WMI query
+  strcpy (argv[0], argv1);
+  strcpy (argv[1], "-U");
+  strcpy (argv[2], username);
+  strcat (argv[2], "%");
+  strcat (argv[2], password);
+  strcpy (argv[3], "//");
+  strcat (argv[3], host);
+
   tree_cell *retc = alloc_tree_cell (0, NULL);
   if (!retc)
     return NULL;
 
   retc->type = CONST_INT;
-  value = wmi_connect_rsop (username, password, host, &handle);
+  value = wmi_connect_rsop (argc, argv, &handle);
   if (value == -1)
     {
-      fprintf (stderr, "nasl_wmi_connect_rsop: WMI RSOP Connect failed\n");
+      fprintf (stderr, "nasl_wmi_connect_rsop: WMI Connect failed\n");
       return NULL;
     }
 
@@ -336,11 +379,15 @@ nasl_wmi_query_rsop (lex_ctxt * lexic)
 tree_cell *
 nasl_wmi_connect_reg (lex_ctxt * lexic)
 {
-  char *host = get_str_local_var_by_name (lexic, "host");
-  char *username = get_str_local_var_by_name (lexic, "username");
-  char *password = get_str_local_var_by_name (lexic, "password");
+  IMPORT (host);
+  IMPORT (username);
+  IMPORT (password);
+  char *argv[4];
+
   WMI_HANDLE handle;
-  int value;
+  int argc = 4, value;
+  char *argv1 = "wmic";
+  char *argv2 = "-U";
 
   if ((host == NULL) || (username == NULL) || (password == NULL))
     {
@@ -355,15 +402,29 @@ nasl_wmi_connect_reg (lex_ctxt * lexic)
       return NULL;
     }
 
+  argv[0] = (char *) emalloc (strlen (argv1));
+  argv[1] = (char *) emalloc (strlen (argv2));
+  argv[2] = (char *) emalloc (strlen (username) + strlen (password) + 1);
+  argv[3] = (char *) emalloc (strlen (host) + 2);
+
+  // Construct the WMI query
+  strcpy (argv[0], argv1);
+  strcpy (argv[1], "-U");
+  strcpy (argv[2], username);
+  strcat (argv[2], "%");
+  strcat (argv[2], password);
+  strcpy (argv[3], "//");
+  strcat (argv[3], host);
+
   tree_cell *retc = alloc_tree_cell (0, NULL);
   if (!retc)
     return NULL;
 
   retc->type = CONST_INT;
-  value = wmi_connect_reg (username, password, host, &handle);
+  value = wmi_connect_reg (argc, argv, &handle);
   if (value == -1)
     {
-      fprintf (stderr, "nasl_wmi_connect_reg: WMI REGISTRY Connect failed\n");
+      fprintf (stderr, "nasl_wmi_connect_reg: WMI Connect failed\n");
       return NULL;
     }
 
@@ -392,7 +453,7 @@ nasl_wmi_reg_get_sz (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
   char *key_name = get_str_local_var_by_name (lexic, "key_name");       // REGISTRY value name
 
@@ -441,7 +502,7 @@ nasl_wmi_reg_enum_value (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
 
   char *res = NULL;
@@ -489,7 +550,7 @@ nasl_wmi_reg_enum_key (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
 
   char *res = NULL;
@@ -537,7 +598,7 @@ nasl_wmi_reg_get_bin_val (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
   char *val_name = get_str_local_var_by_name (lexic, "val_name");       // REGISTRY VALUE NAME
 
@@ -586,7 +647,7 @@ nasl_wmi_reg_get_dword_val (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
   char *val_name = get_str_local_var_by_name (lexic, "val_name");       // REGISTRY VALUE NAME
 
@@ -638,7 +699,7 @@ nasl_wmi_reg_get_ex_string_val (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
   char *val_name = get_str_local_var_by_name (lexic, "val_name");       // REGISTRY VALUE NAME
 
@@ -687,7 +748,7 @@ nasl_wmi_reg_get_mul_string_val (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
   char *val_name = get_str_local_var_by_name (lexic, "val_name");       // REGISTRY VALUE NAME
 
@@ -736,7 +797,7 @@ nasl_wmi_reg_get_qword_val (lex_ctxt * lexic)
   if (!handle)
     return NULL;
 
-  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0); // REGISTRY Hive
+  unsigned int hive = get_int_local_var_by_name (lexic, "hive", 0);     // REGISTRY Hive
   char *key = get_str_local_var_by_name (lexic, "key"); // REGISTRY KEY
   char *val_name = get_str_local_var_by_name (lexic, "val_name");       // REGISTRY VALUE NAME
 
