@@ -38,6 +38,12 @@
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
+
+#ifdef _WIN32
+#include <winsock2.h>
+#define sleep Sleep
+#endif
+
 #include <errno.h>
 
 #include "omp.h"
@@ -94,9 +100,9 @@
 /* OMP. */
 
 /**
- * @brief Get the task status from an OMP GET_STATUS response.
+ * @brief Get the task status from an OMP GET_TASKS response.
  *
- * @param[in]  response   GET_STATUS response.
+ * @param[in]  response   GET_TASKS response.
  *
  * @return The entity_text of the status entity if the entity is found, else
  *         NULL.
@@ -432,6 +438,78 @@ omp_start_task (gnutls_session_t* session, const char* task_id)
   return omp_start_task_report (session, task_id, NULL);
 }
 
+/**
+ * @brief Resume or start a task and read the manager response.
+ *
+ * @param[in]   session    Pointer to GNUTLS session.
+ * @param[in]   task_id    ID of task.
+ * @param[out]  report_id  ID of report.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+omp_resume_or_start_task_report (gnutls_session_t* session, const char* task_id,
+                                 char** report_id)
+{
+  if (openvas_server_sendf (session,
+                            "<resume_or_start_task task_id=\"%s\"/>",
+                            task_id)
+      == -1)
+    return -1;
+
+  /* Read the response. */
+
+  entity_t entity = NULL;
+  if (read_entity (session, &entity)) return -1;
+
+  /* Check the response. */
+
+  const char* status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  char first = status[0];
+  if (first == '2')
+    {
+      if (report_id)
+        {
+          entity_t report_id_xml = entity_child (entity, "report_id");
+          if (report_id_xml)
+            *report_id = g_strdup (entity_text (report_id_xml));
+          else
+            {
+              free_entity (entity);
+              return -1;
+            }
+        }
+      free_entity (entity);
+      return 0;
+    }
+  free_entity (entity);
+  return -1;
+}
+
+/**
+ * @brief Resume or start a task and read the manager response.
+ *
+ * @param[in]   session    Pointer to GNUTLS session.
+ * @param[in]   task_id    ID of task.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+omp_resume_or_start_task (gnutls_session_t* session, const char* task_id)
+{
+  return omp_resume_or_start_task_report (session, task_id, NULL);
+}
+
 /** @todo Use this in the other functions. */
 /**
  * @brief Read response and convert status of response to a return value.
@@ -473,7 +551,9 @@ check_response (gnutls_session_t* session)
 
 
 /**
- * @brief Stop a task and read the manager response.
+ * @brief Deprecated wrapper function for /ref omp_stop_task.
+ *
+ * @deprecated Use /ref omp_stop_task instead.
  *
  * @param[in]  session  Pointer to GNUTLS session.
  * @param[in]  id       ID of task.
@@ -482,9 +562,23 @@ check_response (gnutls_session_t* session)
  */
 int
 omp_abort_task (gnutls_session_t* session, const char* id)
+{
+  return omp_stop_task (session, id);
+}
+
+/**
+ * @brief Stop a task and read the manager response.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  id       ID of task.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+omp_stop_task (gnutls_session_t* session, const char* id)
 {
   if (openvas_server_sendf (session,
-                            "<abort_task task_id=\"%s\"/>",
+                            "<stop_task task_id=\"%s\"/>",
                             id)
       == -1)
     return -1;
@@ -540,8 +634,9 @@ get_omp_response_503 (gnutls_session_t* session, const gchar* command,
       return -1;
     }
 }
+
 /**
- * @brief Issue an OMP \<get_nvt_all\/\> command and wait for the response.
+ * @brief Issue an OMP \<get_nvts\/\> command and wait for the response.
  *
  * @param[in]  session   Session to the server.
  * @param[out] response  Entity containing the response, must be freed.
@@ -551,7 +646,7 @@ get_omp_response_503 (gnutls_session_t* session, const gchar* command,
 int
 omp_get_nvt_all (gnutls_session_t* session, entity_t* response)
 {
-  return get_omp_response_503 (session, "<get_nvt_all/>", response);
+  return get_omp_response_503 (session, "<get_nvts details=\"0\"/>", response);
 }
 
 /**
@@ -616,7 +711,7 @@ omp_wait_for_task_start (gnutls_session_t* session,
 {
   while (1)
     {
-      if (openvas_server_sendf (session, "<get_status/>") == -1)
+      if (openvas_server_sendf (session, "<get_tasks/>") == -1)
         return -1;
 
       /* Read the response. */
@@ -720,7 +815,7 @@ omp_wait_for_task_end (gnutls_session_t* session, const char* id)
 {
   while (1)
     {
-      if (openvas_server_sendf (session, "<get_status/>") == -1)
+      if (openvas_server_sendf (session, "<get_tasks/>") == -1)
         return -1;
 
       /* Read the response. */
@@ -828,7 +923,7 @@ omp_wait_for_task_stop (gnutls_session_t* session, const char* id)
 {
   while (1)
     {
-      if (openvas_server_sendf (session, "<get_status/>") == -1)
+      if (openvas_server_sendf (session, "<get_tasks/>") == -1)
         return -1;
 
       /* Read the response. */
@@ -940,7 +1035,7 @@ omp_wait_for_task_delete (gnutls_session_t* session,
       const char* status;
 
       if (openvas_server_sendf (session,
-                                "<get_status task_id=\"%s\"/>",
+                                "<get_tasks task_id=\"%s\"/>",
                                 id)
           == -1)
         return -1;
@@ -978,12 +1073,14 @@ omp_delete_task (gnutls_session_t* session, const char* id)
 }
 
 /**
- * @brief Get the status of a task.
+ * @brief Deprecated wrapper function for /ref omp_get_tasks.
+ *
+ * @deprecated Use /ref omp_get_tasks instead.
  *
  * @param[in]  session         Pointer to GNUTLS session.
  * @param[in]  id              ID of task or NULL for all tasks.
  * @param[in]  include_rcfile  Request rcfile in status if true.
- * @param[out] status          Status return.  On success contains GET_STATUS
+ * @param[out] status          Status return.  On success contains GET_TASKS
  *                             response.
  *
  * @return 0 on success, -1 or OMP response code on error.
@@ -991,6 +1088,25 @@ omp_delete_task (gnutls_session_t* session, const char* id)
 int
 omp_get_status (gnutls_session_t* session, const char* id, int include_rcfile,
                 entity_t* status)
+{
+  return omp_get_tasks (session, id, 1, include_rcfile, status);
+}
+
+/**
+ * @brief Get the status of a task.
+ *
+ * @param[in]  session         Pointer to GNUTLS session.
+ * @param[in]  id              ID of task or NULL for all tasks.
+ * @param[in]  details         Whether to request task details.
+ * @param[in]  include_rcfile  Request rcfile in status if true.
+ * @param[out] status          Status return.  On success contains GET_TASKS
+ *                             response.
+ *
+ * @return 0 on success, -1 or OMP response code on error.
+ */
+int
+omp_get_tasks (gnutls_session_t* session, const char* id, int details,
+               int include_rcfile, entity_t* status)
 {
   const char* status_code;
   int ret;
@@ -998,7 +1114,8 @@ omp_get_status (gnutls_session_t* session, const char* id, int include_rcfile,
   if (id == NULL)
     {
       if (openvas_server_sendf (session,
-                                "<get_status rcfile=\"%i\"/>",
+                                "<get_tasks details=\"%i\" rcfile=\"%i\"/>",
+                                details,
                                 include_rcfile)
           == -1)
         return -1;
@@ -1006,8 +1123,12 @@ omp_get_status (gnutls_session_t* session, const char* id, int include_rcfile,
   else
     {
       if (openvas_server_sendf (session,
-                                "<get_status task_id=\"%s\" rcfile=\"%i\"/>",
+                                "<get_tasks"
+                                " task_id=\"%s\""
+                                " details=\"%i\""
+                                " rcfile=\"%i\"/>",
                                 id,
+                                details,
                                 include_rcfile)
           == -1)
         return -1;
@@ -1054,7 +1175,13 @@ omp_get_report (gnutls_session_t* session,
                 entity_t* response)
 {
   if (openvas_server_sendf (session,
-                            "<get_report format=\"%s\" report_id=\"%s\"/>",
+                            /** @todo Enable after 3.2 release, so that 3.2
+                              *       remains compatible with Manager 1.0. */
+#if 0
+                            "<get_reports format_id=\"%s\" report_id=\"%s\"/>",
+#else
+                            "<get_reports format=\"%s\" report_id=\"%s\"/>",
+#endif
                             format ? format : "nbe",
                             id))
     return -1;
@@ -1070,6 +1197,8 @@ omp_get_report (gnutls_session_t* session,
 /**
  * @brief Get a report in a given format.
  *
+ * @todo This now has a bad name, because there is an OMP GET_REPORT_FORMATS.
+ *
  * @param[in]  session      Pointer to GNUTLS session.
  * @param[in]  id           ID of report.
  * @param[in]  format       Required format.
@@ -1090,7 +1219,13 @@ omp_get_report_format (gnutls_session_t* session,
   entity_t entity;
 
   if (openvas_server_sendf (session,
-                            "<get_report format=\"%s\" report_id=\"%s\"/>",
+                            /** @todo Enable after 3.2 release, so that 3.2
+                              *       remains compatible with Manager 1.0. */
+#if 0
+                            "<get_reports format_id=\"%s\" report_id=\"%s\"/>",
+#else
+                            "<get_reports format=\"%s\" report_id=\"%s\"/>",
+#endif
                             format,
                             id))
     return -1;
@@ -1724,7 +1859,7 @@ omp_delete_agent (gnutls_session_t* session,
  *
  * @param[in]  session         Pointer to GNUTLS session.
  * @param[in]  oid             OID of NVT or NULL for all NVTs.
- * @param[out] response        Status return. On success contains GET_STATUS
+ * @param[out] response        Status return. On success contains GET_TASKS
  *                             response.
  *
  * @return 0 on success, -1 on error.
@@ -1737,9 +1872,16 @@ omp_get_nvt_details_503 (gnutls_session_t* session, const char * oid,
   int ret;
 
   if (oid)
-    request = g_strdup_printf ("<get_nvt_details oid=\"%s\"/>", oid);
+    request = g_strdup_printf ("<get_nvts"
+                               " nvt_oid=\"%s\""
+                               " details=\"1\""
+                               " preferences=\"1\"/>",
+                               oid);
   else
-    request = g_strdup ("<get_nvt_details/>");
+    request = g_strdup ("<get_nvts"
+                        " details=\"1\""
+                        " timeout=\"1\""
+                        " preference_count=\"1\"/>");
 
   ret = get_omp_response_503 (session, request, response);
 
